Attribute VB_Name = "mdlScriptingFileSystemObject"
Option Explicit
'https://docs.microsoft.com/es-es/office/vba/language/reference/user-interface-help/filesystemobject-object

Function sfsoBuildPath(RutaDeAcceso As String, Nombre As String) 'Construir path
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoBuildPath = fsObject.buildpath(RutaDeAcceso, Nombre)
    
    Set fsObject = Nothing
End Function

Sub sfsoCopyFile(Origen As String, Destino As String, Optional ByRef Sobreescritura As Boolean = True)
    'Copiar archivo(s)
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.CopyFile Origen, Destino, Sobreescritura
    
    Set fsObject = Nothing
    
End Sub

Sub sfsoCopyFolder(Origen As String, Destino As String, Optional ByRef Sobreescritura As Boolean = True)
    'Copiar carpeta(s)
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.CopyFolder Origen, Destino, Sobreescritura
    
    Set fsObject = Nothing
    
End Sub

Sub sfsoCreateFolder(Carpeta As String) 'Crear carpeta
    'Las carpetas anteriores deben de existir
    'La nueva carpeta no debe de exisitr
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.createFolder Carpeta
    
    Set fsObject = Nothing
    
End Sub

Function sfsoCreateTextFile(NombreDeArchivo As String, _
                            Optional Sobreescribir As Boolean = True, _
                            Optional Unicode As Boolean = False) As Object
    'Crea un archivo de texto y devuelve un objeto TextStream
    Dim fsObject As Object, fsTextFile As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set fsTextFile = fsObject.CreateTextFile(NombreDeArchivo, Sobreescribir, Unicode)
    
    Set sfsoCreateTextFile = fsTextFile
    
    Set fsObject = Nothing
    Set fsTextFile = Nothing
End Function

Sub sfsoDeleteFile(NombreDeArchivo As String, Optional Forzar As Boolean = False)
    'Borrar archivos
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.DeleteFile NombreDeArchivo, Forzar
    Set fsObject = Nothing
End Sub

Sub sfsoDeleteFolder(NombreDeCarpeta As String, Optional Forzar As Boolean = False)
    'Borrar carpetas
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.DeleteFolder NombreDeCarpeta, Forzar
    Set fsObject = Nothing
End Sub

Function sfsoDriveExists(EspecUnidad As String) As Boolean
    'Comprobar existencia de unidad
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoDriveExists = fsObject.DriveExists(EspecUnidad)
    Set fsObject = Nothing
End Function

Function sfsoFileExists(EspecArchivo As String) As Boolean
    'Comprobar existencia de archivo
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoFileExists = fsObject.FileExists(EspecArchivo)
    Set fsObject = Nothing
End Function

Function sfsoFolderExists(EspecCarpeta As String) As Boolean
    'Comprobar existencia de carpeta
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoFolderExists = fsObject.FolderExists(EspecCarpeta)
    Set fsObject = Nothing
End Function

Function sfsoGetAbsolutePathName(EspecRuta As String) As String
    'Obtener la ruta de acceso absoluta
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetAbsolutePathName = fsObject.GetAbsolutePathName(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetBaseName(EspecRuta As String) As String
    'Obtener el nombre base, sin ruta ni extiensin
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetBaseName = fsObject.GetBaseName(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetDrive(EspecRuta As String) As Object
    'Obtener objeto Drive
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set sfsoGetDrive = fsObject.GetDrive(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetDrives() As Object
    'Obtener coleccin Drives
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set sfsoGetDrives = fsObject.Drives
    Set fsObject = Nothing

End Function

Function sfsoGetDriveName(EspecRuta As String) As String
    'Obtener nombre de la unidad
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetDriveName = fsObject.GetDriveName(sfsoGetAbsolutePathName(EspecRuta))
    Set fsObject = Nothing

End Function

Function sfsoGetExtensionName(EspecRuta As String) As String
    'Obtener la extensin
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetExtensionName = fsObject.GetExtensionName(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetFile(EspecRuta As String) As Object
    'Obtener objeto File
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set sfsoGetFile = fsObject.GetFile(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetFiles(EspecRuta As String) As Object
    'Obtener coleccin Files
    Dim fsObject As Object
    Dim fsFolder As Object
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set fsFolder = fsObject.GetFolder(EspecRuta)
    Set sfsoGetFiles = fsFolder.Files
    Set fsObject = Nothing
    Set fsFolder = Nothing
End Function


Function sfsoGetFileName(EspecRuta As String) As String
    'Obtener nombre del archivo
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetFileName = fsObject.GetFileName(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetFolder(EspecRuta As String) As Object
    'Obtener objeto Folder
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set sfsoGetFolder = fsObject.GetFolder(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetSubFolders(EspecRuta As String) As Object
    'Obtener coleccin Folders
    Dim fsObject As Object
    Dim fsFolder As Object
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set fsFolder = fsObject.GetFolder(EspecRuta)
    Set sfsoGetSubFolders = fsFolder.SubFolders
    Set fsObject = Nothing
    Set fsFolder = Nothing
End Function

Function sfsoGetParentFolderName(EspecRuta As String) As String
    'Obtener nombre de la carpeta contenedora del ltimo elemento de la ruta
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetParentFolderName = fsObject.GetParentFolderName(EspecRuta)
    Set fsObject = Nothing

End Function

Function sfsoGetSpecialFolder(EspecCarpeta As Integer) As Object
    'Obtener objeto Folder correspondiente a una carpeta del sistema
    'EspecCarpeta = 0; Windows
    '             = 1; System
    '             = 2; Temp
    
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set sfsoGetSpecialFolder = fsObject.GetSpecialFolder(EspecCarpeta)
    Set fsObject = Nothing

End Function

Function sfsoGetTempName() As String
    'Obtener nombre aleatorio para archivo temporal
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    sfsoGetTempName = fsObject.GetTempName()
    Set fsObject = Nothing

End Function

Sub sfsoMoveFile(Origen As String, Destino As String)
    'Mover archivo(s)
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.MoveFile Origen, Destino
    
    Set fsObject = Nothing
    
End Sub

Sub sfsoMoveFolder(Origen As String, Destino As String)
    'Mover carpeta(s)
    Dim fsObject As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    fsObject.MoveFolder Origen, Destino
    
    Set fsObject = Nothing
    
End Sub


Function sfsoOpenTextFile(NombreDeArchivo As String, _
                            Optional ModoIO As Integer = 1, _
                            Optional Crear As Boolean = False, _
                            Optional Formato As Integer = 0)
    'Abrir un archivo de texto y obtener el objeto TextStream correspondiente
    Dim fsObject As Object, fsTextFile As Object
    
    Set fsObject = CreateObject("Scripting.FileSystemObject")
    Set fsTextFile = fsObject.OpenTextFile(NombreDeArchivo, ModoIO, Crear, Formato)
    
    Set sfsoOpenTextFile = fsTextFile
    
    Set fsObject = Nothing
    Set fsTextFile = Nothing
End Function

'Objeto File. Devuleto por sfsoGetFile
    'Propiedades: Attributes        Largo
                ' DateCreated       Fecha-Hora
                ' DateLastAccessed  Fecha-Hora
                ' DateLastModified  Fecha-Hora
                ' Drive             Objeto Drive
                ' Name              Texto
                ' ParentFolder      Objeto Folder
                ' Path              Texto
                ' ShortName         Texto
                ' ShortPath         Texto
                ' Size              Largo
                ' Type              Texto
    'Mtodos:   ' Copy ...
                ' Delete
                ' Move ...
                ' OpenAsTextStream  Objeto TextStream
                
'Objeto Folder. Devuelto por sfsoGetFolder
    'Propiedades: Files             Coleccin Files
                ' IsRootFolder      Booleano
                ' SubFolders        Coleccin Folders
    'Mtodos:   ' AddFolders
    
'Objeto Drive. Devuelto por sfsoGetDrive
    'Propiedades: AvailableSpace    Doble
                ' DriveLetter       String
                ' DriveType         Largo
                ' FileSystem        Texto
                ' FreeSpace         Largo
                ' IsReady           Boolean
                ' RootFolder        Folder
                ' SerialNumber      Long
                ' ShareName         String
                ' TotalSize         Doble
                ' VolumeName        String

'Objeto TextStream. Devuelto por sfsoCreateTextFile y por el mtodo OpenAsTextStream del objeto File
    'Propiedades: AtEndOfLine       Booleano
                ' AtEndOfStream     Booleano
                ' Column            Largo
                ' Line              Largo
    'Mtodos:     Close
                ' Read(Caracteres)
                ' ReadAll
                ' ReadLine
                ' Skip(Caracteres)
                ' SkipLine
                ' Write(Cadena)
                ' WriteBlackLines(Lneas)
                ' WriteLine(Cadena)
